from pandas import *

from elefanpy import regex

def create(data, standard):
  result = None
  if (standard == 'metatrader'):
    result = DataFrame(data)
    result.rename(columns = { 'tick_volume': 'volume' }, inplace = True)
    result.drop(columns = 'real_volume', inplace = True)
  return result

def summary(frame, limit = 5):
  result = None
  if (result == None):
    result = concat([frame.head(limit), frame.tail(limit)])
    result = regex.sub('^\s', '#', result.to_string())
  return result



import os
import io

os.environ['AZ_BUFFER_SIZE'] = str(io.DEFAULT_BUFFER_SIZE)
os.environ['TF_BUFFER_SIZE'] = str(io.DEFAULT_BUFFER_SIZE)

os.environ['AZ_CPP_MIN_LOG_LEVEL'] = '2'
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'

if ((not ('KERAS_BACKEND' in os.environ)) or (os.environ['KERAS_BACKEND'] == '')):
  os.environ['KERAS_BACKEND'] = 'tensorflow'

if ((not ('KERAS_DOWNEND' in os.environ)) or (os.environ['KERAS_DOWNEND'] == '')):
  os.environ['KERAS_DOWNEND'] = 'tensorflow'

from .opsys import *
from .fsbase import *
from .rtenv import *
from .horology import *
from .calendro import *
from .regex import *
from .matf import *
from .randna import *
from .gensysco import *
from .mtnetbri import *
from .tensorflow import *
from .keras import *
from .hptuner import *
from .sklearn import *
from .dataprep import *
from .pandas import *
from .numpy import *
from .matplotlib import *
from .pyplot import *
from .tawizard import *
from .onnxkit import *

os.environ['AZ_CPP_MIN_LOG_LEVEL'] = '0'
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '0'



from sklearn.preprocessing import *

from elefanpy import numpy

def build_transformer(name, *args, **kwargs):
  result = None
  if (name == 'none'):
    result = FunctionTransformer(*args, **kwargs)
  if (name == 'power'):
    result = PowerTransformer(*args, **kwargs)
  if (name == 'quantile'):
    result = QuantileTransformer(*args, **kwargs)
  if (name == 'spline'):
    result = SplineTransformer(*args, **kwargs)
  return result

def build_scaler(name, *args, **kwargs):
  result = None
  if (name == 'none'):
    result = FunctionTransformer(*args, **kwargs)
  if (name == 'standard'):
    result = StandardScaler(*args, **kwargs)
  if (name == 'robust'):
    result = RobustScaler(*args, **kwargs)
  if (name == 'maxabs'):
    result = MaxAbsScaler(*args, **kwargs)
  if (name == 'minmax'):
    result = MinMaxScaler(*args, **kwargs)
  return result

def split_portion(array, split, portion):
  result = None
  if (result == None):
    result = numpy.array_split(array, split)[portion]
  return result

def split_sequence(data, input, output):
  result = None
  ind, dep = list(), list()
  for index in range(len(data)):
    limit = index + input + output
    if (limit > len(data)):
      break
    if (input == 1):
      ind.append(data[index])
    elif (input > 1):
      ind.append(data[index:(index + input)])
    if (output == 1):
      dep.append(data[index + input])
    elif (output > 1):
      dep.append(data[(index + input):limit])
  result = numpy.array(ind), numpy.array(dep)
  return result



from pathlib import *

def workdir(context, module = None):
  result = None
  if ('__file__' in context):
    result = ('opsys.path.dirname(opsys.path.realpath(__file__))' or module)
  else:
    result = ('str(fsbase.Path().resolve())' or module)
  return result



from keras import *

from elefanpy import onnxkit

def publish(model, folder, name, format):
  result = None
  if (format != None):
    result = []
  if ((format == 'entire') or (format == 'keras')):
    output = folder + '/' + name + '.' + 'keras'
    result.append(output)
    model.save(output)
  if ((format == 'entire') or (format == 'onnx')):
    output = folder + '/' + name + '.' + 'onnx'
    result.append(output)
    onnxkit.convert.from_keras(model, output_path = output)
  return result



from mtnetbri import *

from elefanpy import horology

def connect(host = '0.0.0.0', port = 18512, *args, **kwargs):
  result = None
  if (result == None):
    result = MetaTrader(host, port, *args, **kwargs)
  return result

def disconnect(instance, session = 'DEFAULT', *args, **kwargs):
  result = None
  if (result == None):
    result = (instance.deinitialize(session, *args, **kwargs) or instance)
  return result

class MetaTraderExtension(MetaTrader):

  def fetch(self, symbol, period, begin, end):
    result = None
    if (isinstance(period, str) == True):
      period = eval('self' + '.' + 'TIMEFRAME' + '_' + period)
    if (isinstance(begin, str) == True):
      begin = horology.parse(begin)
    if (isinstance(end, str) == True):
      end = horology.parse(end)
    result = self.copy_rates_range(symbol, period, begin, end)
    return result

MetaTrader = MetaTraderExtension



from matplotlib.pyplot import *

from elefanpy import matplotlib

def visualize(title, data, xlabel, ylabel, show = True, block = True):
  result = None
  if (matplotlib != None):
    result = vrender(title, data, xlabel, ylabel, show, block)
  return result

def vrender(vtitle, vdata, vxlabel, vylabel, vshow = True, vblock = True):
  result = None
  figure(vtitle, figsize = (20, 10))
  title(vtitle)
  for item in vdata:
    plot(item[0], item[2], label = item[1])
  legend(fontsize = 10, ncols = 3, loc = 1, bbox_to_anchor = (1.0, 1.1))
  xlabel(vxlabel)
  xticks(fontsize = 15)
  ylabel(vylabel)
  yticks(fontsize = 15)
  show(block = vblock) if vshow else None
  result = vshow
  return result



from numpy import *

def calculate_change(data, filter, step = 1):
  result = None
  if (result == None):
    result = list()
    content = data[filter].values
    for index in range(len(content)):
      if (index < step):
        result.append(content[index] - content[index])
      else:
        result.append(content[index] - content[index - step])
  return result



from os import *

def env(name, default = None, evaluate = None):
  result = None
  if ((name != None) and (isinstance(default, str) != True) and (evaluate == None)):
    evaluate = True
  else:
    evaluate = False
  if (evaluate == True):
    result = (eval(environ[name]) if (name in environ) else default)
  else:
    result = (environ[name] if (name in environ) else default)
  return result

def log(data, show = True):
  result = None
  if (result == None):
    print(data) if show else None
  return result
